@@ -86,7 +86,7 @@
 #define KWAYLANDSERVER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDSERVER_NO_DEPRECATED
-#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51704
+#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51802
 #endif
 #ifdef KWAYLANDSERVER_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,12 +96,12 @@
 #  ifdef KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x51704
+#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x51802
 #  endif
 #endif
 
 #ifndef KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
-#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0
+#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x50000
 #endif
 
 #ifdef KWAYLANDSERVER_DEPRECATED
@@ -110,46 +110,6 @@
 #  define KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
 
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x50500
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_5(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_5(text)
-#endif
-
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x51c00
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_28(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_28(text)
-#endif
-
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x53200
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_50(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_50(text)
-#endif
-
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x53400
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_52(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_52(text)
-#endif
-
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x54500
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_69(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_69(text)
-#endif
-#define KWAYLANDSERVER_DEPRECATED_VERSION_5(minor, text)      KWAYLANDSERVER_DEPRECATED_VERSION_5_##minor(text)
-#define KWAYLANDSERVER_DEPRECATED_VERSION(major, minor, text) KWAYLANDSERVER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KWAYLANDSERVER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDSERVER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KWAYLANDSERVER_DEPRECATED_VERSION(major, minor, text)
-#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDSERVER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
-
 #endif /* KWAYLANDSERVER_EXPORT_H */
 
 
@@ -204,7 +164,7 @@
 #define KWAYLANDSERVER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDSERVER_NO_DEPRECATED
-#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51704
+#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51802
 #endif
 #ifdef KWAYLANDSERVER_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0
@@ -214,12 +174,12 @@
 #  ifdef KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x51704
+#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x51802
 #  endif
 #endif
 
 #ifndef KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
-#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0
+#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x50000
 #endif
 
 #ifdef KWAYLANDSERVER_DEPRECATED
@@ -228,45 +188,5 @@
 #  define KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
 
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x50500
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_5(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_5(text)
-#endif
-
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x51c00
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_28(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_28(text)
-#endif
-
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x53200
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_50(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_50(text)
-#endif
-
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x53400
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_52(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_52(text)
-#endif
-
-#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x54500
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_69(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_69(text)
-#endif
-#define KWAYLANDSERVER_DEPRECATED_VERSION_5(minor, text)      KWAYLANDSERVER_DEPRECATED_VERSION_5_##minor(text)
-#define KWAYLANDSERVER_DEPRECATED_VERSION(major, minor, text) KWAYLANDSERVER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KWAYLANDSERVER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDSERVER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KWAYLANDSERVER_DEPRECATED_VERSION(major, minor, text)
-#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDSERVER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KWAYLANDSERVER_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
-
 
 #endif /* ECM_GENERATEEXPORTHEADER_KWAYLANDSERVER_EXPORT_H */
